'use strict';

exports.__esModule = true;

var _electron = require('electron');

var setApplicationMenu = function setApplicationMenu() {
    var name = _electron.app.getName();

    // https://github.com/electron/electron/blob/master/docs/api/menu/
    var windowsMenu = {
        label: 'Window',
        role: 'window',
        submenu: [{
            label: 'Minimize',
            accelerator: 'CmdOrCtrl+M',
            role: 'minimize'
        }, {
            label: 'Close',
            accelerator: 'CmdOrCtrl+W',
            role: 'close'
        }]
    };

    var template = [{
        label: 'View',
        submenu: [{
            label: 'Reload',
            accelerator: 'CmdOrCtrl+R',
            click: function click(item, focusedWindow) {
                if (focusedWindow) {
                    focusedWindow.reload();
                }
            }
        }, {
            type: 'separator'
        }, {
            label: 'Toggle Full Screen',
            accelerator: process.platform === 'darwin' ? 'Ctrl+Command+F' : 'F11',
            click: function click(item, focusedWindow) {
                if (focusedWindow) {
                    focusedWindow.setFullScreen(!focusedWindow.isFullScreen());
                }
            }
        }, {
            label: 'Zoom',
            submenu: [{
                label: 'Zoom In',
                role: 'zoomin'
            }, {
                label: 'Zoom Out',
                role: 'zoomout'
            }, {
                label: 'Reset',
                role: 'resetzoom'
            }]
        }, {
            type: 'separator'
        }, {
            label: 'Toggle Developer Tools',
            accelerator: process.platform === 'darwin' ? 'Alt+Command+I' : 'Ctrl+Shift+I',
            click: function click(item, focusedWindow) {
                if (focusedWindow) {
                    focusedWindow.toggleDevTools();
                }
            }
        }]
    }, windowsMenu, {
        label: 'Help',
        role: 'help',
        submenu: [{
            label: 'Help',
            click: function click() {
                _electron.shell.openExternal('https://snapmaker.com/support/');
            }
        }]
    }];

    if (process.platform === 'darwin') {
        template.unshift({
            label: name,
            submenu: [{
                label: 'About ' + name,
                role: 'about'
            }, {
                type: 'separator'
            }, {
                label: 'Services',
                role: 'services',
                submenu: []
            }, {
                type: 'separator'
            }, {
                label: 'Hide ' + name,
                accelerator: 'Command+H',
                role: 'hide'
            }, {
                label: 'Hide Others',
                accelerator: 'Command+Alt+H',
                role: 'hideothers'
            }, {
                label: 'Show All',
                role: 'unhide'
            }, {
                type: 'separator'
            }, {
                label: 'Quit',
                accelerator: 'Command+Q',
                click: function click() {
                    _electron.app.quit();
                }
            }]
        });

        // Window menu
        windowsMenu.submenu.push({
            type: 'separator'
        }, {
            label: 'Bring All to Front',
            role: 'front'
        });
    }

    var appMenu = _electron.Menu.buildFromTemplate(template);
    _electron.Menu.setApplicationMenu(appMenu);
}; /* eslint import/no-unresolved: 0 */
exports.default = setApplicationMenu;