'use strict';

var _electron = require('electron');

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _desktop = require('./desktop');

var _cnc = require('./cnc');

var _cnc2 = _interopRequireDefault(_cnc);

var _package = require('./package.json');

var _package2 = _interopRequireDefault(_package);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var windowManager = null; /* eslint import/no-unresolved: 0 */


var main = function main() {
    if ((0, _desktop.handleStartupEvent)()) {
        return;
    }

    // https://github.com/electron/electron/blob/master/docs/api/app.md#appmakesingleinstancecallback
    var shouldQuit = _electron.app.makeSingleInstance(function (commandLine, workingDirectory) {
        // Someone tried to run a second instance, we should focus our window.
        if (!windowManager) {
            return;
        }

        var window = windowManager.getWindow();
        if (window) {
            if (window.isMinimized()) {
                window.restore();
            }
            window.focus();
        }
    });

    if (shouldQuit) {
        _electron.app.quit();
        return;
    }

    // Create the user data directory if it does not exist
    var userData = _electron.app.getPath('userData');
    _mkdirp2.default.sync(userData);

    _electron.app.commandLine.appendSwitch('ignore-gpu-blacklist');
    _electron.app.on('ready', function () {
        (0, _cnc2.default)({ host: '127.0.0.1', port: 0 }, function (err, server) {
            if (err) {
                console.error('Error:', err);
                return;
            }

            var address = server.address();
            if (!address) {
                console.error('Unable to start the server:', address);
                return;
            }

            (0, _desktop.setApplicationMenu)();

            windowManager = new _desktop.WindowManager();
            windowManager.openWindow({
                title: _package2.default.name + ' ' + _package2.default.version,
                url: 'http://' + address.address + ':' + address.port
            });
        });
    });
};

main();