'use strict';

var fs = require('fs');

var COPYFILE_EXCL = 1;
var SIZE = 65536;

module.exports.constants = {
    COPYFILE_EXCL: COPYFILE_EXCL
};

module.exports = fs.copyFileSync || copyFileSync;

function copyFileSync(src, dest, flag) {
    check(src, dest, flag);
    
    var writeFlag = flag === COPYFILE_EXCL ? 'wx' : 'w';
    
    var ref = fs.statSync(src);
    var size = ref.size;
    var mode = ref.mode;
    
    var fdSrc = fs.openSync(src, 'r');
    var fdDest = fs.openSync(dest, writeFlag, mode);
    
    var length = size < SIZE ? size : SIZE;
    
    var position = 0;
    var peaceSize = size < SIZE ? 0 : size % SIZE;
    var offset = 0;
    
    var buffer = Buffer.allocUnsafe(length);
    for (var i = 0; length + position + peaceSize <= size; i++, position = length * i) {
        fs.readSync(fdSrc, buffer, offset, length, position);
        fs.writeSync(fdDest, buffer, offset, length, position);
    }
    
    if (peaceSize) {
        var length$1 = peaceSize;
        buffer = Buffer.allocUnsafe(length$1);
        
        fs.readSync(fdSrc, buffer, offset, length$1, position);
        fs.writeSync(fdDest, buffer, offset, length$1, position);
    }
    
    fs.closeSync(fdSrc);
    fs.closeSync(fdDest);
}

function check(src, dest, flags) {
    if (typeof dest !== 'string')
        { throw TypeError('dest must be a string'); }
    
    if (typeof src !== 'string')
        { throw TypeError('src must be a string'); }
    
    if (typeof flags === 'number' && flags && flags !== COPYFILE_EXCL)
        { throw Error(("EINVAL: invalid argument, copyfile -> '" + dest + "'")); }
}

